# Changelog

<!-- version list -->

## [v0.1.0](https://github.com/bilelomrani1/hatch-cada/releases/tag/v0.1.0) (2025-12-31)
### Features

- First release by [@bilelomrani1](https://github.com/bilelomrani1) ([a665b50](https://github.com/bilelomrani1/hatch-cada/commit/a665b5044f43f3d7f84d03ad7f483c0501a44311))
